@@ -1,8 +1,7 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8; coding: utf-8 -*- */
-/* gtksourcespacedrawer-private.h
+/*
  * This file is part of GtkSourceView
  *
- * Copyright (C) 2016 - Sébastien Wilmet <swilmet@gnome.org>
+ * Copyright 2016 - Sébastien Wilmet <swilmet@gnome.org>
  *
  * GtkSourceView is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -18,24 +17,21 @@
  * along with this library; if not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef GTK_SOURCE_SPACE_DRAWER_PRIVATE_H
-#define GTK_SOURCE_SPACE_DRAWER_PRIVATE_H
+#pragma once
 
 #include <gtk/gtk.h>
+
 #include "gtksourcetypes.h"
 #include "gtksourcetypes-private.h"
 
 G_BEGIN_DECLS
 
 GTK_SOURCE_INTERNAL
-void			_gtk_source_space_drawer_update_color		(GtkSourceSpaceDrawer *drawer,
-									 GtkSourceView        *view);
-
+void _gtk_source_space_drawer_update_color (GtkSourceSpaceDrawer *drawer,
+                                            GtkSourceView        *view);
 GTK_SOURCE_INTERNAL
-void			_gtk_source_space_drawer_draw			(GtkSourceSpaceDrawer *drawer,
-									 GtkSourceView        *view,
-									 cairo_t              *cr);
+void _gtk_source_space_drawer_draw         (GtkSourceSpaceDrawer *drawer,
+                                            GtkSourceView        *view,
+                                            GtkSnapshot          *snapshot);
 
 G_END_DECLS
-
-#endif /* GTK_SOURCE_SPACE_DRAWER_PRIVATE_H */
