@@ -61,12 +61,14 @@ gtk_source_vim_command_bar_dispose (GObject *object)
 
 	g_clear_pointer (&self->typed, g_free);
 
-	if (self->buffer == NULL)
+	if (self->buffer != NULL)
 	{
 		g_string_free (self->buffer, TRUE);
 		self->buffer = NULL;
 	}
 
+	g_clear_object (&self->command);
+
 	G_OBJECT_CLASS (gtk_source_vim_command_bar_parent_class)->dispose (object);
 }
 
@@ -170,7 +172,7 @@ do_execute (GtkSourceVimCommandBar *self,
 
 	if (history->len > MAX_HISTORY)
 	{
-		g_ptr_array_set_size (history, MAX_HISTORY);
+		g_ptr_array_remove_range (history, 0, history->len - MAX_HISTORY);
 	}
 
 	g_ptr_array_add (history, g_strdup (command));
